==> owncloud-10.2.0.zip: owncloud/settings/l10n/hy.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Սխալ գաղտնաբառ",
    "Unable to change password" : "Չկարողացա փոխել գաղտնաբառը",
    "Unable to delete group." : "Չկարողացա ջնջել խումբը",
    "Saved" : "Պահված",
    "Email sent" : "Էլ. նամակը ուղարկվեց",
    "Invalid mail address" : "Անվավեր էլ. հասցե",
    "Unable to delete user." : "Չկարողացա ջնջել օգտատիրոջը",
    "Forbidden" : "Արգելված",
    "Invalid user" : "Անվավեր օգտատեր",
    "Unable to change mail address" : "Չկարողացա փոխել էլ. հասցեն",
    "Unable to change full name" : "Չկարողացա փոխել լրիվ անունը",
    "Language changed" : "Լեզուն փոխվեց",
    "Invalid request" : "Անվավեր հայց",
    "Unknown user" : "Անհայտ օգտատեր",
    "All" : "Ամենը",
    "Enabled" : "Միացված",
    "Not enabled" : "Չմիացված",
    "Updating...." : "Թարմացնում եմ...",
    "Updated" : "Թարմացվեց",
    "App update" : "Ափփ թարմացում",
    "Experimental" : "Փորձարարական",
    "Valid until {date}" : "Վավեր մինչ {date}",
    "Delete" : "Ջնջել",
    "Disconnect" : "Անջատել",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Groups" : "Խմբեր",
    "undo" : "ետարկել",
    "never" : "երբեք",
    "deleted {userName}" : "ջնջված {userName}",
    "add group" : "խումբ ավելացնել",
    "Cheers!" : "Չը՛խկ",
    "Forum" : "Ֆորում",
    "by %s" : "%s կողմից",
    "days" : "օր",
    "Log" : "Լոգ",
    "Server address" : "Սերվերի հասցե",
    "Port" : "Պորտ",
    "Send email" : "Ուղարկել նամակ",
    "Android app" : "Android ափփ",
    "iOS app" : "iOS ափփ",
    "Cancel" : "Չեղարկել",
    "Full name" : "Լրիվ անուն",
    "Email" : "Էլ. հասցե",
    "Password" : "Գաղտնաբառ",
    "Current password" : "Ընթացիկ գաղտնաբառ",
    "New password" : "Նոր գաղտնաբառ",
    "Change password" : "Փոխել գաղտնաբառը",
    "Language" : "Լեզու",
    "Help translate" : "Օգնել թարգմանել",
    "Unlimited" : "Անսահման",
    "Browser" : "Զննիչ",
    "Name" : "Անուն",
    "Username" : "Օգտանուն",
    "Version" : "Տարբերակ",
    "Personal" : "Անձնական",
    "Admin" : "Ադմին",
    "Error" : "Սխալ",
    "E-Mail" : "Էլ. նամակ",
    "Create" : "Ստեղծել",
    "Add Group" : "Ավելացնել խումբ",
    "Group" : "Խումբ",
    "Everyone" : "Բոլորը",
    "Admins" : "Ադմիններ",
    "Other" : "Այլ",
    "Full Name" : "Լրիվ անուն",
    "Last Login" : "Վերջին մուտք",
    "change full name" : "փոխել լրիվ անունը",
    "change email address" : "փոխել էլ. հասցեն",
    "Default" : "Լռելյայն",
    "Share" : "Կիսվել",
    "Add" : "Ավելացնել"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/hy.js <==
OC.L10N.register(
    "settings",
    {
    "Unable to change password" : "Չկարողացա փոխել գաղտնաբառը",
    "Unable to delete group." : "Չկարողացա ջնջել խումբը",
    "Saved" : "Պահված",
    "Email sent" : "Էլ. նամակը ուղարկվեց",
    "Invalid mail address" : "Անվավեր էլ. հասցե",
    "Unable to delete user." : "Չկարողացա ջնջել օգտատիրոջը",
    "Forbidden" : "Արգելված",
    "Invalid user" : "Անվավեր օգտատեր",
    "Unable to change mail address" : "Չկարողացա փոխել էլ. հասցեն",
    "Unable to change full name" : "Չկարողացա փոխել լրիվ անունը",
    "Create" : "Ստեղծել",
    "Delete" : "Ջնջել",
    "Share" : "Կիսվել",
    "Language changed" : "Լեզուն փոխվեց",
    "Invalid request" : "Անվավեր հայց",
    "Unknown user" : "Անհայտ օգտատեր",
    "All" : "Ամենը",
    "Enabled" : "Միացված",
    "Not enabled" : "Չմիացված",
    "Updating...." : "Թարմացնում եմ...",
    "Updated" : "Թարմացվեց",
    "App update" : "Ափփ թարմացում",
    "Experimental" : "Փորձարարական",
    "Valid until {date}" : "Վավեր մինչ {date}",
    "Disconnect" : "Անջատել",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Groups" : "Խմբեր",
    "undo" : "ետարկել",
    "never" : "երբեք",
    "deleted {userName}" : "ջնջված {userName}",
    "add group" : "խումբ ավելացնել",
    "enabled" : "միացված",
    "Cheers!" : "Չը՛խկ",
    "Forum" : "Ֆորում",
    "Language" : "Լեզու",
    "by %s" : "%s կողմից",
    "days" : "օր",
    "Log" : "Լոգ",
    "Server address" : "Սերվերի հասցե",
    "Port" : "Պորտ",
    "Send email" : "Ուղարկել նամակ",
    "Android app" : "Android ափփ",
    "iOS app" : "iOS ափփ",
    "Add" : "Ավելացնել",
    "Cancel" : "Չեղարկել",
    "Full name" : "Լրիվ անուն",
    "Email" : "Էլ. հասցե",
    "Password" : "Գաղտնաբառ",
    "Current password" : "Ընթացիկ գաղտնաբառ",
    "New password" : "Նոր գաղտնաբառ",
    "Change password" : "Փոխել գաղտնաբառը",
    "Help translate" : "Օգնել թարգմանել",
    "Browser" : "Զննիչ",
    "Name" : "Անուն",
    "Username" : "Օգտանուն",
    "Version" : "Տարբերակ",
    "New Password" : "Նոր գաղտնաբառ",
    "Personal" : "Անձնական",
    "Admin" : "Ադմին",
    "Other" : "Այլ",
    "Settings" : "Կարգավորումներ",
    "E-Mail" : "Էլ. նամակ",
    "Add Group" : "Ավելացնել խումբ",
    "Group" : "Խումբ",
    "Everyone" : "Բոլորը",
    "Admins" : "Ադմիններ",
    "Unlimited" : "Անսահման",
    "Full Name" : "Լրիվ անուն",
    "Last Login" : "Վերջին մուտք",
    "change full name" : "փոխել լրիվ անունը",
    "change email address" : "փոխել էլ. հասցեն",
    "Default" : "Լռելյայն"
},
"nplurals=2; plural=(n != 1);");
